@@ -1,12 +1,7 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 import sys
-
-try:
-    from mock import patch
-except ImportError:
-    from unittest.mock import patch
+from unittest.mock import patch
 
 from csvkit.utilities.csvgrep import CSVGrep, launch_new_instance
 from tests.utils import ColumnsTests, CSVKitTestCase, EmptyFileTests, NamesTests
@@ -42,13 +37,13 @@ class TestCSVGrep(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
     def test_match_utf8(self):
         self.assertRows(['-c', '3', '-m', 'ʤ', 'examples/test_utf8.csv'], [
             ['foo', 'bar', 'baz'],
-            ['4', '5', u'ʤ'],
+            ['4', '5', 'ʤ'],
         ])
 
     def test_match_utf8_bom(self):
         self.assertRows(['-c', '3', '-m', 'ʤ', 'examples/test_utf8_bom.csv'], [
             ['foo', 'bar', 'baz'],
-            ['4', '5', u'ʤ'],
+            ['4', '5', 'ʤ'],
         ])
 
     def test_no_match(self):
@@ -71,7 +66,7 @@ class TestCSVGrep(CSVKitTestCase, ColumnsTests, EmptyFileTests, NamesTests):
     def test_re_match_utf8(self):
         self.assertRows(['-c', '3', '-r', 'ʤ', 'examples/test_utf8.csv'], [
             ['foo', 'bar', 'baz'],
-            ['4', '5', u'ʤ'],
+            ['4', '5', 'ʤ'],
         ])
 
     def test_string_match(self):
