@@ -1,15 +1,9 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 import json
 import sys
-
-import six
-
-try:
-    from mock import patch
-except ImportError:
-    from unittest.mock import patch
+from io import StringIO
+from unittest.mock import patch
 
 from csvkit.utilities.csvjson import CSVJSON, launch_new_instance
 from tests.utils import CSVKitTestCase, EmptyFileTests
@@ -59,18 +53,18 @@ class TestCSVJSON(CSVKitTestCase, EmptyFileTests):
         output = self.get_output(['-i', '4', 'examples/dummy.csv'])
         js = json.loads(output)
         self.assertDictEqual(js[0], {'a': True, 'c': 3.0, 'b': 2.0})
-        six.assertRegex(self, output, '        "a": true,')
+        self.assertRegex(output, '        "a": true,')
 
     def test_keying(self):
         js = json.loads(self.get_output(['-k', 'a', 'examples/dummy.csv']))
         self.assertDictEqual(js, {'True': {'a': True, 'c': 3.0, 'b': 2.0}})
 
     def test_duplicate_keys(self):
-        output_file = six.StringIO()
+        output_file = StringIO()
         utility = CSVJSON(['-k', 'a', 'examples/dummy3.csv'], output_file)
-        six.assertRaisesRegex(self, ValueError,
-                              'Value True is not unique in the key column.',
-                              utility.run)
+        self.assertRaisesRegex(ValueError,
+                               'Value True is not unique in the key column.',
+                               utility.run)
         output_file.close()
 
     def test_geojson_with_id(self):
